@@ -6,8 +6,8 @@ S3_DATALAKE = os.getenv("S3_DATALAKE")
 S3_STAGING_PROCESSED = os.getenv("S3_STAGING_PROCESSED")
 S3_DATALAKE = os.getenv("S3_DATALAKE")
 DDB_STAGE_TRIGGER = os.getenv("DDB_STAGE_TRIGGER")
-DDB_STAGE_CONTROL = os.getenv("DDB_STAGE_CONTROL")
-DDB_STAGE_CONTROL_LOG = os.getenv("DDB_STAGE_CONTROL_LOG")
+DDB_STAGE_CONTROL = os.getenv("DDB_STAGE")
+DDB_STAGE_CONTROL_LOG = os.getenv("DDB_STAGE_LOG")
 DDB_STAGE_CONTROL_FILE_BINLOG = os.getenv("DDB_STAGE_CONTROL_FILE_BINLOG")
 DDB_CUSTOMER = os.getenv("DDB_CUSTOMER")
 DDB_PARAM = os.getenv("DDB_PARAM")
