@@ -15,12 +15,12 @@ class Pandas:
 
     # You can pass list or string path or .parquet
     def get_parquet(self, path):
-        self.logger.info("Starting GetParquet {}".format(path))
+        self.logger.debug("Starting GetParquet {}".format(path))
 
         keys_s3 = self.s3.get_list_parquet(path)
-        self.logger.info("S3keys {}".format(keys_s3))
+        self.logger.debug("S3keys {}".format(keys_s3))
         if len(keys_s3) == 0:
-            self.logger.info("Finishing GetParquet")
+            self.logger.debug("Finishing GetParquet")
             return pd.DataFrame()
 
         df = wr.s3.read_parquet(
@@ -29,15 +29,15 @@ class Pandas:
             validate_schema=False
         )
 
-        self.logger.info("Finishing GetParquet")
+        self.logger.debug("Finishing GetParquet")
 
         return df
 
     def write_parquet(self, df, path, database, table, mode, partition_cols, list_path_delete):
-        self.logger.info("Starting Write Parquet")
+        self.logger.debug("Starting Write Parquet")
 
         if (list_path_delete is not None) & (mode != "append"):
-            self.logger.info(
+            self.logger.debug(
                 "list_path_delete => {}"
                 .format(list_path_delete)
             )
@@ -47,7 +47,7 @@ class Pandas:
             )
 
         if df.empty:
-            self.logger.info("DF Write Parquet None or only lines with delete")
+            self.logger.debug("DF Write Parquet None or only lines with delete")
         else:
             df["dt_process_parq"] = self.utils.date_time()
             df["dt_process_parq"] = pd.to_datetime(df["dt_process_parq"])
@@ -74,7 +74,7 @@ class Pandas:
                     compression='snappy'
                 )
 
-        self.logger.info("Finishing Write Parquet")
+        self.logger.debug("Finishing Write Parquet")
 
     def print_dtypes(self, df):
         self.logger.debug("Starting print_dtypes")
